# PySALESetup

PySALESetup is a preprocessing tool designed for use with [iSALE2D](https://www.iSALE-code.de).
It is a python module that allows for the setup of complex geometries in 2D simulations.
This is of particular use in granular mesoscale numerical simulations and example 
scripts are also included. read the documentation [here](https://jgd10.github.io/PySALESetup/).

This package is a work-in-progress and is developed when I have time to work on it.
It will be released as soon as I can to pypi, but for now there is a lot to do.
